
# q-expansion of newform 2736.2.dc.d, downloaded from the LMFDB on 09 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 2736
weight = 2
poly_data = [6561, 0, 7290, 0, 3726, 0, 1134, 0, 315, 0, 126, 0, 46, 0, 10, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[282852, 0, 214407, 0, 57834, 0, 8496, 0, 5175, 0, 2584, 0, 523, 0, 1, 0], 12393], [[0, 165726, 0, 84240, 0, 18360, 0, 3654, 0, 2658, 0, 1088, 0, 152, 0, -4], 12393], [[-5832, 0, -2997, 0, -1134, 0, -315, 0, -126, 0, -46, 0, -10, 0, -1, 0], 729], [[0, 87480, 0, 63018, 0, 8262, 0, 126, 0, 1845, 0, 850, 0, 58, 0, -23], 37179], [[-126117, 0, -111942, 0, -41310, 0, -8946, 0, -3087, 0, -1598, 0, -446, 0, -50, 0], 12393], [[38880, 0, 41472, 0, 15606, 0, 3303, 0, 939, 0, 527, 0, 158, 0, 20, 0], 4131], [[-122472, 0, -26811, 0, 13770, 0, 3465, 0, -900, 0, -34, 0, 218, 0, 56, 0], 12393], [[2592, 0, 5427, 0, 3060, 0, 873, 0, 168, 0, 85, 0, 40, 0, 7, 0], 1377], [[-46899, 0, -36531, 0, -13311, 0, -2853, 0, -1038, 0, -493, 0, -133, 0, -22, 0], 4131], [[0, 254421, 0, 272484, 0, 104652, 0, 21483, 0, 7119, 0, 4012, 0, 1168, 0, 133], 37179], [[0, -794610, 0, -625887, 0, -195534, 0, -39726, 0, -16848, 0, -8177, 0, -2003, 0, -158], 37179], [[0, -41067, 0, -44631, 0, -17901, 0, -3834, 0, -1221, 0, -646, 0, -196, 0, -19], 4131], [[0, 325134, 0, 82701, 0, -34425, 0, -12348, 0, 1566, 0, 238, 0, -635, 0, -194], 37179], [[0, 137781, 0, 131544, 0, 52326, 0, 11115, 0, 3690, 0, 1819, 0, 541, 0, 73], 12393], [[0, -433026, 0, -545616, 0, -231336, 0, -53424, 0, -14832, 0, -7888, 0, -2560, 0, -346], 37179]]

hecke_ring_character_values = [[1711, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [2053, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1217, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1009, [1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0], [1, 0, 0, 1, 0, 0, 0, -1, -1, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 1, 0, 0, 0, 0], [2, -1, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, -1, -1, -1], [0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1], [2, 0, 0, 1, 0, 2, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, -1, 0, 2, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 1, 0, 0, 0, 0, 0, 1, 1, 0, 2, 0, -1], [-1, 0, 0, -1, 0, -1, 1, -2, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1, -1], [0, 0, 0, 0, 4, 0, 0, 0, 0, 0, -2, -1, 0, 1, 0, 0], [0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 2, 1, 0, 2, 0, 0], [2, 0, 0, 0, 0, 2, -1, 0, 3, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 1, 0, 2, -1, 1, 1, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 2, 0], [0, -1, 0, 0, 0, -5, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0], [3, -2, 0, 1, 0, 1, 1, 0, 0, 2, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0], [0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 1, 2, -1, -2, -1, 0], [1, -1, 0, -1, 0, 1, -1, -1, -2, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 1, -1, 1, 1, 1], [-1, 1, 0, -1, 0, 0, 1, 2, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -2, 2, -2, 1, 1, 0], [-9, 0, 0, 1, 0, -5, 1, -1, -2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 4, -2, -2, -1, 1, 0], [3, 0, 0, 1, 0, -2, 1, -1, -2, 3, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 1, -2], [-2, 2, 0, -1, 0, -1, 0, 1, 2, -1, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0, 0, -1], [-1, -1, 0, 1, 0, -4, -1, -3, 2, 0, 0, 0, 0, 0, 0, 0], [-2, 0, 0, -2, 0, 5, 2, -2, 0, 0, 0, 0, 0, 0, 0, 0], [6, -2, 0, 2, 0, 0, 2, -3, -5, 4, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 2, 0, 0, 0, 0, 0, -1, 0, 2, 0, 2, 0], [0, 0, 0, 0, -2, 0, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0], [0, 0, 2, 0, 1, 0, 0, 0, 0, 0, -2, 0, 2, 0, -1, -4], [4, 0, 0, -1, 0, -5, 0, 1, 1, -1, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 3, -1, 0], [1, -1, 0, 1, 0, 0, 1, 1, 2, 1, 0, 0, 0, 0, 0, 0], [0, 0, -4, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, 2, -3, 0], [-4, -2, 0, 1, 0, -5, 4, -1, -2, 1, 0, 0, 0, 0, 0, 0], [-9, 4, 0, -3, 0, -3, -3, 2, 4, -4, 0, 0, 0, 0, 0, 0], [21, -3, 0, 3, 0, 9, 3, -2, -4, 3, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 2, 0, 0, 0, 0, 0, -4, -2, 2, -1, -1, 0], [14, -1, 0, 2, 0, 0, 1, 2, 1, 2, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, -3, 0, 0, 0, 0, 0, 3, 1, -3, 0, 0, 2], [0, 0, -1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0], [-4, 0, 0, -1, 0, 3, 1, -3, -2, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 3, 1, -3, 1], [0, 0, 2, 0, 4, 0, 0, 0, 0, 0, -2, 1, 2, -1, 2, -1], [0, 0, 4, 0, -2, 0, 0, 0, 0, 0, 2, 2, -3, 0, 0, -4], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 2, 2, 1], [0, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, -1, 0, 2, 0, 0, 1, 2, 1, 2, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 2, 0, 0, 0, 0, 0, -1, 2, -2, -2, -2, 0], [4, 0, 0, 4, 0, 0, -4, -4, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, 2, 0, 0, 0, 0, 0, -4, -8, 2, -4, -1, 4], [7, 0, 0, -3, 0, 5, -3, 1, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 3, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [13, 0, 0, 0, 0, 13, 1, 0, -5, 0, 0, 0, 0, 0, 0, 0], [0, 0, -4, 0, 4, 0, 0, 0, 0, 0, -2, -3, 0, 3, 0, 2], [0, -2, 0, 1, 0, -2, 0, 2, -4, 0, 0, 0, 0, 0, 0, 0], [-3, -2, 0, 1, 0, -2, 1, 1, 2, 2, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 1, -6, 3, 0, 0, 0], [-8, 1, 0, 0, 0, 0, -1, 6, 7, -2, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, -6, 0, 0, 0, 0, 0, 0, 0, 0, -1, -2, 0], [0, 0, 3, 0, -4, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, -3], [-2, 2, 0, -1, 0, -1, -2, 1, 6, -1, 0, 0, 0, 0, 0, 0], [-9, 1, 0, 0, 0, -18, -1, -2, 3, 0, 0, 0, 0, 0, 0, 0], [-3, -1, 0, -2, 0, -2, 5, 3, -4, 0, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, 3, 0, 0, 0, 0, 0, 3, 0, -2, 0, 4, 2], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 2, -6, 2, 6, 2], [3, 3, 0, 3, 0, -16, -3, 3, 0, 3, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 5, 2, -1, 4, 2, 0], [7, 0, 0, 4, 0, -3, -1, -4, -3, 2, 0, 0, 0, 0, 0, 0], [0, 0, 4, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, -2, -2, 0], [1, -2, 0, -1, 0, 1, -1, -1, -2, 2, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, -8, 0, 0, 0, 0, 0, 4, 0, 1, 0, 1, -1], [-8, 0, 0, -4, 0, 4, -1, 4, 5, -6, 0, 0, 0, 0, 0, 0], [-12, -3, 0, 0, 0, -6, 0, -7, -14, 3, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 6, 0, 6, 0, -3], [0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, -4, 4, -2, -2, -4], [5, 0, 0, -3, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, -3, 0, -2, 0, 0, 0, 0, 0, 2, 1, -3, 0, 0, 3], [-5, -1, 0, -5, 0, 0, 1, 8, 7, 2, 0, 0, 0, 0, 0, 0], [0, 0, 3, 0, -11, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -6, 2, 5, 2, -5, -1], [3, -1, 0, 3, 0, 0, -5, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -4, 0, 0, 0, 0, 0, 0, 0, 0, -2, -3, 0, 0, 4], [0, -1, 0, 0, 0, -22, 0, 1, 0, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 2, 2, -2, -1], [0, 0, -2, 0, -4, 0, 0, 0, 0, 0, 2, -2, -1, 2, -1, 1], [0, 0, 2, 0, -6, 0, 0, 0, 0, 0, 12, -2, 2, -1, -1, -4], [-14, 0, 0, -2, 0, 12, 2, 4, 1, 2, 0, 0, 0, 0, 0, 0], [5, 4, 0, -2, 0, 7, 2, 2, 6, -2, 0, 0, 0, 0, 0, 0], [11, 0, 0, 2, 0, -9, -3, 4, 4, -4, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -10, 0, 1, 0, -1, -1], [0, 0, -1, 0, -1, 0, 0, 0, 0, 0, 2, 2, -6, 1, 3, 2], [0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 2, 2, -8, 1, 4, 0], [-12, 2, 0, 2, 0, 0, -2, 1, 3, -4, 0, 0, 0, 0, 0, 0], [-16, 2, 0, -1, 0, 0, -2, -1, 1, -4, 0, 0, 0, 0, 0, 0], [0, 0, -5, 0, 13, 0, 0, 0, 0, 0, -13, -4, 0, 0, 0, 5], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, -8, -1, -8, 1, 7], [0, 0, 6, 0, -2, 0, 0, 0, 0, 0, 1, 0, -2, 0, -2, -3], [7, -6, 0, 3, 0, 8, 0, -3, -3, 0, 0, 0, 0, 0, 0, 0], [-3, 5, 0, 0, 0, -6, -5, 7, -2, 0, 0, 0, 0, 0, 0, 0], [3, 1, 0, 3, 0, -5, -3, -1, 0, 1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, -3, -5, -3, 5, 2], [6, -2, 0, -4, 0, 0, 2, -3, -5, 4, 0, 0, 0, 0, 0, 0], [-20, 0, 0, 0, 0, -20, -2, 0, 3, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 1, 0, 0, 0, 0, 0, 1, -1, 3, -2, -6, -1], [2, 3, 0, 2, 0, 2, -2, -5, 0, 3, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, -6, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0], [0, 0, 4, 0, -5, 0, 0, 0, 0, 0, 0, 0, 0, -3, -5, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 2, 1, 2, 0], [-2, 0, 0, 2, 0, 4, -2, 6, 4, -2, 0, 0, 0, 0, 0, 0], [1, 2, 0, 1, 0, 0, -4, 1, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, 2, 0, 0, 0, 0, 0, -4, -4, 2, -2, -1, 4], [0, 0, 0, 0, -6, 0, 0, 0, 0, 0, 12, 2, -2, 1, 1, 0], [-8, 0, 0, 0, 0, 0, 0, -6, -6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 4, 0, 3, 0, 0, 0, 0, 0, -3, 2, 6, 0, 0, -4], [6, -4, 0, 2, 0, 4, 1, -2, -9, 2, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, 1, 0, 0, 0, 0, 0, -1, 2, -3, 0, 0, 2], [3, 0, 0, 3, 0, 7, -3, 0, 0, 0, 0, 0, 0, 0, 0, 0], [5, 3, 0, 0, 0, 0, -3, 6, 9, -6, 0, 0, 0, 0, 0, 0], [8, -3, 0, 8, 0, 10, -8, -1, 0, -3, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, 5, 0, 0, 0, 0, 0, 5, 2, 2, 4, -4, -2], [7, 0, 0, 7, 0, 0, -3, -1, -1, 1, 0, 0, 0, 0, 0, 0], [3, 2, 0, 3, 0, -22, -3, 5, 0, 2, 0, 0, 0, 0, 0, 0], [0, 0, -5, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, 1, 3, 0], [19, 4, 0, -2, 0, 21, -4, 2, 2, -2, 0, 0, 0, 0, 0, 0], [0, 0, 8, 0, -6, 0, 0, 0, 0, 0, 3, -1, 1, 1, 1, -4], [-10, -2, 0, -2, 0, -16, 6, 1, -3, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 1, 0, 0, 0, 0, 0, -2, -6, -6, -3, 3, 2], [0, 0, 1, 0, 13, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0], [11, 0, 0, 3, 0, -8, -3, 5, 4, -3, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 12, -2, 12, 2, -4], [11, -6, 0, 3, 0, 8, 5, -3, -10, 3, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, 12, 0, 0, 0, 0, 0, -6, -2, -2, 2, -2, -1], [5, -2, 0, -1, 0, 12, 4, -1, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, -1, 1, -2, -2, -3], [2, -1, 0, 2, 0, -19, -2, -8, 0, -1, 0, 0, 0, 0, 0, 0], [0, 0, -4, 0, -6, 0, 0, 0, 0, 0, -6, -2, 3, -4, -6, -4], [-5, 6, 0, -3, 0, -2, -11, 3, 9, -3, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 2, 0, 0, 0, 0, 0, -4, 0, -2, 0, 1, -2], [-6, 1, 0, 4, 0, -5, 4, 6, 12, -1, 0, 0, 0, 0, 0, 0], [0, 0, -4, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 6, -4, 0], [-7, 8, 0, -4, 0, -3, -5, 4, 10, -4, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, -8, 0, 0, 0, 0, 0, 4, -3, 0, 3, 0, -1], [8, 2, 0, -4, 0, 6, -4, 0, 0, -2, 0, 0, 0, 0, 0, 0], [0, 0, -3, 0, 3, 0, 0, 0, 0, 0, -6, 2, -4, 1, 2, 6], [-31, 3, 0, -5, 0, 0, -3, 4, 7, -6, 0, 0, 0, 0, 0, 0], [0, 0, -5, 0, -3, 0, 0, 0, 0, 0, 3, 2, 2, 0, 0, 5], [11, -2, 0, 1, 0, 10, 2, -1, 3, 1, 0, 0, 0, 0, 0, 0], [0, 0, 6, 0, 8, 0, 0, 0, 0, 0, -4, 0, 2, 0, 2, -3], [0, 0, -1, 0, -12, 0, 0, 0, 0, 0, 12, -2, -1, 0, 0, 1], [0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 1, -2, -1, -4, 2, 1], [-5, 2, 0, -5, 0, -23, 5, 6, 0, 2, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, -4, 0, 0, 0, 0, 0, -4, 0, 3, 0, -6, 2], [0, 0, -2, 0, 1, 0, 0, 0, 0, 0, -2, 10, -6, 5, 3, 4], [0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, -1, -2, -2, 4, -2], [-11, 7, 0, -5, 0, -3, -5, -2, -4, -7, 0, 0, 0, 0, 0, 0], [13, 0, 0, 0, 0, 13, -2, 0, -2, 0, 0, 0, 0, 0, 0, 0], [8, -4, 0, 4, 0, 2, 4, -2, -4, 4, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 5, 0, 5, 0, -5], [0, 0, -1, 0, -4, 0, 0, 0, 0, 0, 8, -2, -4, -1, 2, 2], [21, 0, 0, -3, 0, 12, -3, -5, -10, 0, 0, 0, 0, 0, 0, 0], [0, 0, 5, 0, -15, 0, 0, 0, 0, 0, 15, 7, 1, 0, 0, -5], [-9, -4, 0, 1, 0, 0, 4, 9, 5, 8, 0, 0, 0, 0, 0, 0], [-3, 0, 0, 1, 0, 4, 3, 5, -1, 7, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -4, 3, -4, -3, -5], [-4, -6, 0, 3, 0, -7, 8, -3, -16, 3, 0, 0, 0, 0, 0, 0], [0, 0, -6, 0, 16, 0, 0, 0, 0, 0, -16, -2, 3, 0, 0, 6], [14, -2, 0, 2, 0, 24, -2, -3, 1, 0, 0, 0, 0, 0, 0, 0], [-4, 0, 0, -4, 0, 3, 4, -2, 0, 0, 0, 0, 0, 0, 0, 0], [-19, 0, 0, 0, 0, -19, 3, 0, -3, 0, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, -3, 0, 0, 0, 0, 0, 6, -2, 8, -1, -4, -4], [-8, 0, 0, 3, 0, 11, -3, 5, 4, -3, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, 3, 0, 0, 0, 0, 0, 3, 8, -4, 16, 8, -2], [0, 0, -3, 0, 7, 0, 0, 0, 0, 0, 0, 0, 0, -7, -3, 0], [0, 0, 4, 0, -8, 0, 0, 0, 0, 0, 0, 0, 0, -12, -5, 0], [17, 0, 0, 10, 0, -7, -1, 6, -1, 8, 0, 0, 0, 0, 0, 0], [-18, 1, 0, -2, 0, -8, -2, -3, -6, -1, 0, 0, 0, 0, 0, 0], [-12, -2, 0, 1, 0, -26, 0, -3, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 7, -2, 0], [-9, 0, 0, -6, 0, 3, 2, -10, -4, -2, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 7, 0, 7, 0, -8], [-7, -5, 0, 0, 0, -14, 5, 5, -10, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 5, 0, 0, 0, 0, 0, 5, 1, -3, 2, 6, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, -10, 3, -10, -3, 5], [0, 0, 0, 0, -6, 0, 0, 0, 0, 0, 3, -1, 2, 1, 2, 0], [-6, 6, 0, -3, 0, -3, -4, 3, 7, -3, 0, 0, 0, 0, 0, 0], [2, -4, 0, 2, 0, -7, -2, -2, 0, -4, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0], [0, 0, -1, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, -1, -9, 0], [0, 0, -8, 0, 22, 0, 0, 0, 0, 0, -11, -4, -1, 4, -1, 4], [9, 0, 0, -2, 0, -11, 5, -2, -5, 8, 0, 0, 0, 0, 0, 0], [-39, -2, 0, 1, 0, -20, 1, -3, -6, 2, 0, 0, 0, 0, 0, 0], [-9, -8, 0, 3, 0, -6, 3, -5, -10, 8, 0, 0, 0, 0, 0, 0], [0, 0, -4, 0, 15, 0, 0, 0, 0, 0, -15, -2, -1, 0, 0, 4], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 5, 0, 5, 0, 1], [-5, 6, 0, -3, 0, -2, -7, 3, 16, -3, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 2, 0, 0, 0, 0, 0, -1, 3, -2, -3, -2, 0], [0, 0, 3, 0, 4, 0, 0, 0, 0, 0, -4, 0, 0, 0, 0, -3], [2, 8, 0, -4, 0, 12, 0, -3, 11, 0, 0, 0, 0, 0, 0, 0], [3, 2, 0, 3, 0, -22, -3, -1, 0, 2, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, -5, 1, -5, -1, -5], [7, 1, 0, 2, 0, 0, -1, -5, -4, -2, 0, 0, 0, 0, 0, 0], [0, 0, -8, 0, -2, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 4], [0, 0, -3, 0, -5, 0, 0, 0, 0, 0, 10, 8, -10, 4, 5, 6], [0, 0, 0, 7, 0, 7, -1, 17, 6, 5, 0, 0, 0, 0, 0, 0], [-6, 3, 0, -6, 0, -2, 6, 0, 0, 3, 0, 0, 0, 0, 0, 0], [0, 0, 5, 0, -4, 0, 0, 0, 0, 0, 8, 6, 0, 3, 0, -10], [0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 0, 8, -4, 4, 2, -6], [0, 0, -1, 0, -16, 0, 0, 0, 0, 0, 16, 1, -3, 0, 0, 1], [14, 0, 0, 4, 0, -10, -3, 4, 3, -2, 0, 0, 0, 0, 0, 0], [14, 0, 0, 0, 0, 28, 0, -5, 5, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 2, -3, -4, -6, 8, 0], [-6, 8, 0, -6, 0, -10, 6, 7, 0, 8, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 7, 0, 0, 0, 0, 0, 7, -1, 2, -2, -4, 1], [-15, -6, 0, 3, 0, -18, 6, -3, -1, 3, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, 2, 0, 0, 0, 0, 0, -4, 0, 6, 0, -3, -4], [0, 0, -1, 0, 1, 0, 0, 0, 0, 0, 1, 4, -2, 8, 4, -1], [8, 7, 0, -4, 0, 6, -4, 6, 12, -7, 0, 0, 0, 0, 0, 0], [0, 0, -6, 0, 13, 0, 0, 0, 0, 0, 0, 0, 0, -7, -6, 0], [10, 2, 0, -1, 0, 11, -3, 1, 0, -1, 0, 0, 0, 0, 0, 0], [-11, 0, 0, -3, 0, 8, 3, 21, 9, 3, 0, 0, 0, 0, 0, 0], [8, 6, 0, -3, 0, 22, 0, -1, 7, 0, 0, 0, 0, 0, 0, 0], [0, 0, 3, 0, -8, 0, 0, 0, 0, 0, 16, 8, -4, 4, 2, -6], [31, -5, 0, 1, 0, 0, 5, -5, -10, 10, 0, 0, 0, 0, 0, 0], [0, 0, -7, 0, 18, 0, 0, 0, 0, 0, -18, -13, 0, 0, 0, 7], [-25, 2, 0, 1, 0, 0, -2, 11, 13, -4, 0, 0, 0, 0, 0, 0], [0, 0, -4, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, -2, -6, 0], [0, 0, 2, 0, 15, 0, 0, 0, 0, 0, -15, 1, 6, 0, 0, -2], [0, 0, -2, 0, 20, 0, 0, 0, 0, 0, -10, 3, 1, -3, 1, 1], [0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, -7, -3, -14, 6, 6], [21, 3, 0, -5, 0, 0, -3, 11, 14, -6, 0, 0, 0, 0, 0, 0], [7, -4, 0, 2, 0, 5, 7, -2, 6, 2, 0, 0, 0, 0, 0, 0], [-4, 0, 0, -7, 0, -3, 7, -9, -8, 7, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, 3, 0, 0, 0, 0, 0, 3, 4, -3, 8, 6, 2], [0, 0, 9, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -7, 0, 0], [38, 0, 0, 0, 0, 38, -10, 0, 8, 0, 0, 0, 0, 0, 0, 0], [0, 0, -8, 0, 12, 0, 0, 0, 0, 0, -6, -5, 0, 5, 0, 4], [24, -6, 0, 4, 0, 10, 4, -3, -6, 6, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 7, 12, -4, 12, 4, -11], [4, 3, 0, 5, 0, 0, -3, 5, 8, -6, 0, 0, 0, 0, 0, 0], [0, 0, -6, 0, 7, 0, 0, 0, 0, 0, -7, -6, 0, 0, 0, 6], [0, 0, 7, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, -5, -10, 0], [-6, 0, 0, 7, 0, 13, -4, 1, 1, -1, 0, 0, 0, 0, 0, 0], [0, 0, 4, 0, -12, 0, 0, 0, 0, 0, 12, -3, 1, 0, 0, -4], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, -4, -4, -4, 4, 2], [20, -4, 0, 2, 0, 18, 3, -2, 1, 2, 0, 0, 0, 0, 0, 0], [-2, 12, 0, -2, 0, 0, -8, 1, 11, 0, 0, 0, 0, 0, 0, 0], [0, 0, -2, 0, 4, 0, 0, 0, 0, 0, 4, -4, 2, -8, -4, -2], [-17, 6, 0, -3, 0, -14, 4, 3, -5, -3, 0, 0, 0, 0, 0, 0], [3, 0, 0, 13, 0, 10, -7, -7, -3, -1, 0, 0, 0, 0, 0, 0], [0, 0, 2, 0, 1, 0, 0, 0, 0, 0, 1, 2, 2, 4, -4, 2], [-5, -4, 0, -5, 0, 18, 5, -1, 0, -4, 0, 0, 0, 0, 0, 0], [-2, -11, 0, 4, 0, -3, 4, -4, -8, 11, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -8, -13, 3, -13, -3, 12], [11, -9, 0, 7, 0, 8, -5, -10, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 7, 0, 1, 0, 0, 0, 0, 0, -2, 2, 0, 1, 0, -14], [0, 0, 2, 0, -3, 0, 0, 0, 0, 0, 0, 0, 0, -9, -4, 0], [6, 0, 0, 6, 0, 0, 0, -8, -7, 6, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 3, 2, 3, -2, 1], [-15, 2, 0, 1, 0, -32, -4, -3, 5, 0, 0, 0, 0, 0, 0, 0], [20, 2, 0, 1, 0, 38, -4, 9, -7, 0, 0, 0, 0, 0, 0, 0], [0, 4, 0, 0, 0, -14, 0, 2, 0, 4, 0, 0, 0, 0, 0, 0], [-52, 0, 0, -2, 0, 0, 0, -2, -2, 0, 0, 0, 0, 0, 0, 0], [-23, 0, 0, -3, 0, 20, 0, -1, 1, -3, 0, 0, 0, 0, 0, 0], [1, -7, 0, 1, 0, -17, -1, 6, 0, -7, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -3, 9, 0], [41, 0, 0, -7, 0, 24, -7, 1, 2, 0, 0, 0, 0, 0, 0, 0], [12, 0, 0, 3, 0, -9, 3, 1, -4, 9, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, -6, 1, -6, -1, 8], [0, 0, -5, 0, -7, 0, 0, 0, 0, 0, 14, -12, -10, -6, 5, 10], [-25, 3, 0, -5, 0, 0, -3, -5, -2, -6, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 7, 3, 7, -3, 2], [-6, 1, 0, 1, 0, -14, -3, -5, 6, 0, 0, 0, 0, 0, 0, 0], [-3, -6, 0, -3, 0, -17, 3, 9, 0, -6, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -10, -2, -12, -2, 12, 3], [-19, -2, 0, 12, 0, 0, 2, -8, -10, 4, 0, 0, 0, 0, 0, 0], [0, 0, -6, 0, -16, 0, 0, 0, 0, 0, 8, 3, 0, -3, 0, 3], [-3, -2, 0, -3, 0, -17, 3, 4, 0, -2, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 1, 0, 0, 0, 0, 0, -2, 14, 2, 7, -1, -2], [0, 0, -10, 0, -15, 0, 0, 0, 0, 0, 0, 0, 0, -1, -3, 0], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 1, 0], [0, 0, -12, 0, 20, 0, 0, 0, 0, 0, -10, 0, 1, 0, 1, 6], [0, 0, 6, 0, 4, 0, 0, 0, 0, 0, -8, 0, 2, 0, -1, -12], [16, -6, 0, 2, 0, 7, 2, -2, -4, 6, 0, 0, 0, 0, 0, 0], [0, 0, 8, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, -1, -1, 0], [-7, 0, 0, 3, 0, 10, 1, 13, 4, 5, 0, 0, 0, 0, 0, 0], [0, 0, 7, 0, 3, 0, 0, 0, 0, 0, -3, 4, -3, 0, 0, -7], [0, 0, -2, 0, 0, 0, 0, 0, 0, 0, 0, -5, 2, -10, -4, -2], [20, -2, 0, 12, 0, 0, 2, -1, -3, 4, 0, 0, 0, 0, 0, 0], [-7, 5, 0, -7, 0, 21, 7, 3, 0, 5, 0, 0, 0, 0, 0, 0], [0, 0, -5, 0, -2, 0, 0, 0, 0, 0, -2, 6, 1, 12, -2, -5], [6, -12, 0, 6, 0, 0, -2, -6, -19, 6, 0, 0, 0, 0, 0, 0]]
